@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 ##############################################################
 # smscon_master - remote control master for Nokia N900 phone #
-# $Id: smscon_master.py 150 2012-01-15 19:54:20Z yablacky $
+# $Id: smscon_master.py 186 2012-05-31 19:58:29Z yablacky $
 ##############################################################
 
 import os
@@ -138,6 +138,9 @@ def ShowOptions(Level = 1):
         print '   -del config        : Delete %s file' % ConfigDisplayName
         print '   -del script        : Delete %s file' % ScriptDisplayName
         print '   -sendsms number message : Send one SMS message to number. Number may be verbatim "MASTERNUMBER"'
+        print '   -sendemail recipient subject message [attachment-filename [attachment-mimetype]]: Send email.'
+        print '                        If recipient is a single char the EMAILADDRESS from configuration is used.'
+        print '                        The email is accepted and send only if smscon_deamon is running.'
     
         if os.geteuid() != 0:
             print 'WARNING: %s must run as "root". You are currently not "root".' % NAME
@@ -151,6 +154,7 @@ def ShowHiddenOptions():
     print '   -branch            : Show branch number. Deprecated. Removed in future. Shows -version now.'
     print '   -build             : Show build number.  Deprecated. Removed in future. Shows -version now.'
     print '   -init!             : Create default %s files. Do not upgrade existing ones.' % ' & '.join((ConfigDisplayName, ScriptDisplayName))
+    print '   -reload            : Tell daemon to read config file again (-force-reload is also accepted).'
     print '   -get name "default": Get user setting'
     print '   -test "test"       : Run developer test (gps1, gps2, ssh, ssh-off, cam, sms, email1, email2, call, script)'
     print '   -comtest "command" : Run %s command as if received as SMS message (no prefix/suffix required)' % NAME
@@ -184,7 +188,10 @@ def DoCommandLine():
         OriMode = Mode = args.pop(0)
         # Allow all options to start with the usual double dash as well:
         if len(Mode) > 3 and Mode[0:2] == '--' and Mode[3:1] != '-':
-            Mode = Mode[1:] 
+            Mode = Mode[1:]
+        # Allow bare word options to control service (called this way by /etc/init.d/rc) 
+        elif Mode in ('start', 'restart', 'stop', 'reload' 'force-reload') and len(args) == 0:
+            Mode = '-' + Mode; 
 
         if   Mode == '-help':       ShowOptions(1) 
         elif Mode == '-help2':      ShowOptions(2) 
@@ -269,6 +276,9 @@ def DoCommandLine():
             settingsChangeCount += abs(restoreCount)
             ok = restoreCount > 0 and ok
 
+        elif Mode in ('-reload', '-force-reload'):
+            ok = daemon.tell(daemon.TELL_RELOAD) and ok
+
         elif Mode in ('-start', '-restart'):
             if not IsFileReadable(InstPath, ConfigFile):
                 return TellError('Config file %s not present. Use -init.' % ConfigFile)
@@ -295,7 +305,7 @@ def DoCommandLine():
 
         elif Mode == '-reset':
             if (daemon.stop() + remosh.stop() + script.stop()):
-                time.sleep(DelaySeconds) 
+                time.sleep(DelaySeconds)
             ok = DeleteFile(BootPath, BootFile) and ok
             ok = DeleteFile(InstPath, CodeFile) and ok
             ok = DeleteFile(InstPath, ConfigFile) and ok
@@ -355,7 +365,7 @@ def DoCommandLine():
             print ourConf.get(ConfigVar, ConfigValue)
 
         elif Mode == '-sendsms':
-            if len(args) < 2: return TellError("%s requires 2 arguments." % Mode)
+            if len(args) < 2: return TellError("%s requires 2 arguments: recipient-number message" % Mode)
             TargetNumber = Recipient = args.pop(0).upper()
             if TargetNumber == 'MASTERNUMBER':
                 TargetNumber = ourConf.get('MASTERNUMBER', '')
@@ -371,6 +381,21 @@ def DoCommandLine():
             else:
                 LOGGER.info('SMS send to %s.' % Recipient)
 
+        elif Mode == '-sendemail':
+            if len(args) < 3: return TellError("%s requires 3 arguments: recipient subject message [attachment-filename [attachment-mimetype]]." % Mode)
+            TargetNumber = Recipient = args.pop(0)
+            if len(Recipient) < 2:
+                Recipient = ourConf.get('EMAILADDRESS', '')
+            if not re.match('^[^@]+@[^@]+$', Recipient):
+                return TellError('Sending EMAIL to %s failed: no email address.' % TargetNumber)
+            Subject, Message =  args.pop(0), args.pop(0)
+            AttachmentInfo = []
+            len(args) > 0 and args[0][0] != '-' and AttachmentInfo.append(args.pop(0))    # AttachmentFileName
+            len(args) > 0 and args[0][0] != '-' and AttachmentInfo.append(args.pop(0))    # AttachmentMimeType
+            if daemon.writeCliCommand(Mode, Recipient, Subject, Message, *AttachmentInfo):
+                LOGGER.info('Sending email to %s successfully queued.' % Recipient)
+            else:
+                return TellError('Sending email to %s failed.' % Recipient)
         else:
             return TellError('Unknown option (%s).' % OriMode)
                 
