@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 ##############################################################
 # smscon_service - remote control daemon for Nokia N900 phone#
-# $Id: smscon_service.py 180 2012-05-22 23:42:47Z yablacky $
+# $Id: smscon_service.py 189 2012-06-04 21:56:37Z yablacky $
 ##############################################################
 
 # standard modules
@@ -105,7 +105,7 @@ def RevealThat(Subject, Text, SendMethod = None, Attachment = None, Attachhint =
     @param string SendMethod Defaults to smscnf.MESSAGESEND
     @param string|none Attachment Name of file to attach (to email only)
     @param string|none Attachhint Hint about the attachment file's MIME type. 
-    @return void
+    @return array with brief recipient information. Empty if nothing sent.
     """
     if  SendMethod == None:
         SendMethod = smscnf.MESSAGESEND
@@ -139,14 +139,15 @@ def RevealThat(Subject, Text, SendMethod = None, Attachment = None, Attachhint =
 
         if EMAILsend(EmailTo     = smscnf.EMAILADDRESS,
                   Subject        = 'NOKIA N900[%s]: %s' % (Hostname, Subject),
-                  Text           = 'Nokia phone "%s" at %s:\n' '%s\n' % (Hostname, GetTimeString(), Text),
-                  SuccessLogMsg  = 'send email message (subject=%s) to <%s>' % (Subject, smscnf.EMAILADDRESS),
+                  Text           = 'Nokia phone "%s" at %s:\n%s\n' % (Hostname, GetTimeString(), Text),
+                  SuccessLogMsg  = 'sent email message (subject=%s) to <%s>' % (Subject, smscnf.EMAILADDRESS),
                   Attachment = Attachment,
                   Attachhint = Attachhint):
             Revealed.append(smscnf.EMAILADDRESS)
 
     if not Revealed:
         LOGGER.info('Message sending disabled by user setting (%s).' % SendMethod)
+    return Revealed
 
 #############################################
 #    SMS
@@ -882,10 +883,10 @@ def ShowSMScommands(SendMethod):
 #   device lock
 #############################################
 
-def PerformDeviceLock():
+def __DoDeviceLock():
     """
-    Lock the phone.
-    @return void
+    Silently lock the phone.
+    @return string Message.
     """
     os.system ('run-standalone.sh \
                dbus-send --system --type=method_call \
@@ -897,15 +898,12 @@ def PerformDeviceLock():
                string:"com.nokia.mce.request" \
                string:"devlock_callback" \
                uint32:"3"')
+    return 'Phone has been locked.'
 
-    LOGGER.info(             'Phone has been locked.')
-    if smscnf.COMMANDREPLY == 'yes':
-        RevealThat('locked', 'Phone has been locked.')
-        
-def PerformDeviceUnlock():
+def __DoDeviceUnlock():
     """
-    Unlock the phone.
-    @return void
+    Silently unlock the phone.
+    @return string Message.
     """
     os.system ('run-standalone.sh \
                dbus-send --system --type=method_call \
@@ -917,9 +915,27 @@ def PerformDeviceUnlock():
                string:"com.nokia.mce.request" \
                string:"devlock_callback" \
                uint32:"0"')
+    return 'Phone has been unlocked.'
 
-    LOGGER.info(         'Phone has been unlocked.')
-    RevealThat('unlock', 'Phone has been unlocked.')
+def PerformDeviceLock(Reason = ''):
+    """
+    Perform full phone locking operation.
+    @param string Reason.
+    @return void.
+    """
+    Msg = __DoDeviceLock() + Reason
+    LOGGER.info(Msg)
+    RevealThat('locked', Msg)
+        
+def PerformDeviceUnlock(Reason = ''):
+    """
+    Perform full phone unlocking operation.
+    @param string Reason.
+    @return void.
+    """
+    Msg = __DoDeviceUnlock() + Reason
+    LOGGER.info(Msg)
+    RevealThat('unlock', Msg)
 
 #############################################
 #   system
@@ -1060,7 +1076,7 @@ def PerformCamera(args = []):
                   Subject =  'NOKIA N900[%s]: %s' % (Hostname, smscnf.COM_CAMERA),
                   Text    =  ['Frontcam picture from Nokia N900 phone:\n',
                               'Taken on %s at %s\n' % (Hostname, GetTimeString())],
-                  SuccessLogMsg  = '(EMAIL) camera picture send to "%s"' % smscnf.EMAILADDRESS,
+                  SuccessLogMsg  = '(EMAIL) camera picture sent to "%s"' % smscnf.EMAILADDRESS,
                   Attachment =  ImageFilename,
                   Attachhint = 'image' )
 
@@ -1771,11 +1787,8 @@ def ReadIMSI():
     @return list of IMSI codes.
     """
     imsi = smscon.IMSIConfiguration()
-    if imsi.load(Silent = True):
-        LOGGER.info('Found %d IMSI code(s) in "%s" file.' % (len(imsi.keys()), imsi.Filename))
-    else:
-        LOGGER.warning('Initalizing new "%s" file with current valid IMSI code.' % imsi.Filename)
-        imsi.update(smscon.GetPhoneCode('IMSI'), '')
+    imsi.load(Silent = True)
+    LOGGER.info('Successfully loaded %d authorized IMSI code(s).' %  len(imsi.keys()))
     return imsi.keys()
 
 def WriteIMSI(newIMSI):
@@ -1785,47 +1798,64 @@ def WriteIMSI(newIMSI):
     """
     imsi = smscon.IMSIConfiguration()
     if imsi.update(newIMSI, ''):
-        LOGGER.info( 'Added IMSI code (%s) to "%s" file.' % (newIMSI, imsi.Filename) )
+        LOGGER.info( 'Successfully authorized new IMSI code "%s".' % newIMSI)
     else:
-        LOGGER.error( 'Failed to add IMSI code (%s) to "%s" file.' % (newIMSI, imsi.Filename) )
+        LOGGER.error( 'Failed to authorize new IMSI code "%s".' % newIMSI)
 
 def ValidateIMSI():
     """
     Check if current used IMSI code from SIM card is authorized.
     """
+    KnownIMSICodes = ReadIMSI();
     CurrentIMSI = smscon.GetPhoneCode('IMSI')
+    DeviceLockStatus = 'Phone lock status unchanged.'
 
     if CurrentIMSI == None:
-        LOGGER.warning( 'SIM card not present (or just inactive if user skipped or failed to enter SIM pin).')
+        # Use silent calls to lock/unlock and RevealThat situation once only:
+        if smscnf.SIMUNLOCK == 'yes':
+            DeviceLockStatus = __DoDeviceUnlock() + ' Because unlock on no SIM.'
+        elif smscnf.SIMUNLOCK == 'locknewsim':
+            DeviceLockStatus = __DoDeviceLock() + ' Because lock no SIM.'
+        elif smscnf.SIMUNLOCK == 'lockalways':
+            DeviceLockStatus = __DoDeviceLock() + ' Because lock always.'
+
+        LOGGER.warning( 'SIM card not present or inactive. %s' % (CurrentIMSI, DeviceLockStatus))
+
         # With some luck internet connection via wlan is available.
         SendMethod = 'email'    # sms would not work w/o a SIM...
         RevealThat('No or skipped SIM',
-                        'SIM card not present (or just inactive if user skipped or failed to enter SIM pin).',
+                        'SIM card not present (or inactive if user skipped or failed to enter SIM pin).' +
+                        '\n' + DeviceLockStatus,
                         SendMethod)
 
-    # compare current IMSI code with saved one or more in code file.
-    elif CurrentIMSI in ReadIMSI():
-        LOGGER.info('SIM card with authorized IMSI code found.')
+    elif CurrentIMSI in KnownIMSICodes:
+        LOGGER.info('SIM card with authorized IMSI code "%s" detected.' % CurrentIMSI)
+        if smscnf.SIMUNLOCK == 'lockalways':
+            PerformDeviceLock(' Because lock always.') 
 
     else:
-        LOGGER.warning('SIM card not yet autorized, IMSI code has changed to "%s".' % CurrentIMSI)
-
-        # save new IMSI code to file
-        WriteIMSI(CurrentIMSI)    
-
-        # auto unlock phone after new SIM is inserted
+        # Use silent calls to lock/unlock and RevealThat situation once only:
         if smscnf.SIMUNLOCK == 'yes':
-            PerformDeviceUnlock()                 
+            DeviceLockStatus = __DoDeviceUnlock() + ' Because unlock on new SIM.'
+        elif smscnf.SIMUNLOCK == 'locknewsim':
+            DeviceLockStatus = __DoDeviceLock() + ' Because lock new SIM.'
+        elif smscnf.SIMUNLOCK == 'lockalways':
+            DeviceLockStatus = __DoDeviceLock() + ' Because lock always.'
+
+        LOGGER.warning('SIM card not yet autorized. New IMSI code is "%s". %s' % (CurrentIMSI, DeviceLockStatus))
 
         SendMethod = smscnf.MESSAGESEND
         if   SendMethod == 'none':  SendMethod = 'sms'
         elif SendMethod == 'email': SendMethod = 'both'
 
-        RevealThat('New SIM', '\n'.join([
+        if RevealThat('New SIM', '\n'.join([
                         'IMSI = %s' % CurrentIMSI,
                         'IMEI = %s' % smscon.GetPhoneCode('IMEI'),
-                        'Telecom Operator = "%s".' % GetOperatorName()
-                    ]), SendMethod)
+                        'Telecom Operator = "%s".' % GetOperatorName(),
+                        DeviceLockStatus
+                    ]), SendMethod):
+            # Do not authorize new SIM before SIM information has been sent!
+            WriteIMSI(CurrentIMSI)
 
 #############################################
 
@@ -1901,14 +1931,14 @@ def DoCommandLine(args):
                     EMAILsend(EmailTo = smscnf.EMAILADDRESS,
                               Subject = 'Test email / Nokia N900',
                               Text = 'Email sending from Nokia N900 phone is successful!',
-                              SuccessLogMsg = 'send test email message to "%s"' % smscnf.EMAILADDRESS)
+                              SuccessLogMsg = 'sent test email message to "%s"' % smscnf.EMAILADDRESS)
                 elif Func == 'email2': # test mode2 for email + frontcam image
                     ImageFilename = TakeFrontCamPicture()
                     if ImageFilename:
                         EMAILsend(EmailTo = smscnf.EMAILADDRESS,
                               Subject =  'Test email / Nokia N900',
                               Text =  'Frontcam picture from Nokia N900 phone:<br>%s<br>' % GetTimeString(),
-                              SuccessLogMsg = 'send email camera picture send to "%s"' % smscnf.EMAILADDRESS,
+                              SuccessLogMsg = 'camera picture sent to "%s"' % smscnf.EMAILADDRESS,
                               Attachment =  ImageFilename,
                               Attachhint = 'image' )
 
@@ -1933,6 +1963,19 @@ def DoCommandLine(args):
             LOGGER.warning('Simulating received SMS message from MASTERNUMBER with "%s" command.' % Command)
             ProcessCommand(Command, SenderPhoneNumber = smscnf.MASTERNUMBER,
                            ExtraInfo = 'SIMULATION!', CommandOrigin = 'CMDLINE', LogIfCmdUnknown = True)    
+        elif Mode == '-sendemail':
+            if len(args) < 3 : return TellError('%s requires at least 3 arguments.' % Mode)
+            Recipient, Subject, Text = args.pop(0), args.pop(0), args.pop(0)
+            AttachmentFileName = len(args) > 0 and args.pop(0)
+            AttachmentMimeType = len(args) > 0 and args.pop(0)
+            Hostname = os.uname()[1]
+
+            EMAILsend(EmailTo = Recipient,
+                  Subject        = 'NOKIA N900[%s]: %s' % (Hostname, Subject),
+                  Text           = 'Nokia phone "%s" at %s:\n%s\n' % (Hostname, GetTimeString(), Text),
+                  SuccessLogMsg  = 'sent email message (subject=%s) to <%s>' % (Subject, Recipient),
+                  Attachment = AttachmentFileName,
+                  Attachhint = AttachmentMimeType)
         else:
             LOGGER.warning('Option error (%s) - ignored' % Mode)
             return CommandLineStatus
@@ -2263,9 +2306,9 @@ def OnLocalCommandAvailable():
             break
         cliArgs = daemon.isCliCommand(Command)
         if cliArgs:
-            LOGGER.info("----- TEST '%s' BEGINS -----" % ' '.join(cliArgs))
+            LOGGER.info("----- CLI PROCESSING '%s' BEGINS -----" % ' '.join(cliArgs))
             DoCommandLine(cliArgs[:])
-            LOGGER.info("----- TEST '%s' DONE -----" % ' '.join(cliArgs))
+            LOGGER.info("----- CLI PROCESSING '%s' DONE -----" % ' '.join(cliArgs))
         else:
             LOGGER.warning('Unknown command "%s" found in local command channel. Ignored.' % Command)
     return False
@@ -2341,6 +2384,9 @@ def main():
         RevealThat('fatal error', ['smscon_daemon crashed.\n', '%s' % e])        
         ExitDaemon('on fatal error')
     
+    except:
+        ExitDaemon('on exception [%s]: %s' % sys.exc_info()[0:2])
+        
     ExitDaemon('on mainloop exit')
 
-#############################################
\ No newline at end of file
+#############################################
