@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 ##############################################################
 # smscon - remote control library for Nokia N900 phone       #
-# $Id: smsconlib.py 171 2012-05-21 00:47:26Z yablacky $
+# $Id: smsconlib.py 188 2012-06-04 21:55:49Z yablacky $
 ##############################################################
 
 # standard modules
@@ -34,7 +34,7 @@ NAME = 'smscon'
 VERSION = '999.1'   # for trunk and private builds etc.
 
 NAME, VERSION = getSysBuildNameAndVersion(NAME, VERSION,
-    headerInfo  = '$Header: https://vcs.maemo.org/svn/smscon/branches/smscon_0.9.19/src/opt/smscon/smsconlib.py 171 2012-05-21 00:47:26Z yablacky $',
+    headerInfo  = '$Header: https://vcs.maemo.org/svn/smscon/branches/smscon_0.10.1/src/opt/smscon/smsconlib.py 188 2012-06-04 21:55:49Z yablacky $',
     dirLevels   = 3 )
     
 XDEBUG   = False        # cross debug (use only if not running on phone)
@@ -802,7 +802,8 @@ class UserConfiguration(Configuration):
 
         # Notification settings
         'COMMANDREPLY':     (_BoolPattern,      'no',               _OPT_PLAIN, '# Send notification if command accepted (yes|no):'),
-        'MESSAGESEND':      ('^(sms|email|both|none)$',     'sms',  _OPT_PLAIN, '# How to send notifications (sms|email|both|none):'),
+        'MESSAGESEND':      (pat('^(sms|email|both|none)$').help('Must be one of "none", "sms", "email" or "both".'),
+                                                'sms',              _OPT_PLAIN, '# How to send notifications (sms|email|both|none):'),
         'ENABLERESEND':     (_BoolPattern,      'no',               _OPT_PLAIN, '# On failure try to re-send reply message (yes|no):'),
         'RESENDTIME':       (_FloatPattern,     '15.0',             _OPT_PLAIN, '# Minutes between message re-send tries:'),
         'RESENDMAXTRY':     (_IntPattern,       '10',               _OPT_PLAIN, '# Maximum number of message re-send tries (0=no limit):'),
@@ -814,12 +815,14 @@ class UserConfiguration(Configuration):
         'GPSPOLLING':       (_IntPattern,       '8',                _OPT_PLAIN, '# Number of minimum GPS coordinate acquisitions for COM_LOCATIONs best of:'),
         'GPSINTERVAL':      (_IntPattern,       '10',               _OPT_PLAIN, '# Seconds between GPS coordinate acquisitions for COM_TRACKON and COM_LOCATION:'),
         'GPSMAXDEVIATION':  (_IntPattern,       '50',               _OPT_PLAIN, '# Meters of minimum accuracy of a GPS coordinate for COM_LOCATION request:'),  
-        'GPSSEND':          ('^(sms|email|both)$',          'sms',  _OPT_PLAIN, '# How to send GPS notifications (sms|email|both):'),
+        'GPSSEND':          (pat('^(sms|email|both)$').help('Must be one of "sms", "email" or "both".'),
+                                                'sms',              _OPT_PLAIN, '# How to send GPS notifications (sms|email|both):'),
 
         # Miscellaneous settings
         'SILENCEDEVICE':    (_BoolPattern,      'no',               _OPT_PLAIN, '# Set phone silent before executing command (yes|no):'),
         'AUTODEVICELOCK':   (_BoolPattern,      'no',               _OPT_PLAIN, '# Lock phone before executing any command except un/lock (yes|no):'),
-        'SIMUNLOCK':        (_BoolPattern,      'no',               _OPT_PLAIN, '# Automatically unlock phone when new SIM is inserted (yes|no):'),
+        'SIMUNLOCK':        (pat('^(no|yes|locknewsim|lockalways)$').help('Must be one of "no", "yes", "locknewsim" or "lockalways"'),
+                                                'no',               _OPT_PLAIN, '# Automatic device un/locking: (no|yes|locknewsim|lockalways):'),
         'DEBUGFLAGS':       ('',                '',                 _OPT_PLAIN, '# A csv with debugging options (for development use only)'),
     
         # Sensor detections
